@@ -1,6 +1,7 @@
 import datetime
 import time
 from random import random
+import logging
 
 file = open("my-property.csv", "a")
 
@@ -12,13 +13,13 @@ try:
     # Finally, we call our function to start generating dum values
     while True:
         current_time = int(datetime.datetime.utcnow().timestamp()*1000)
-        print(current_time)
+        logging.debug(current_time)
         values = (current_time, str(random()), str(random()), str(random()))
         write_in_csv(values)
         # Have a 2-second break
         time.sleep(1)
 
 except Exception:
-    print("hello")
+    logging.error("File exception")
     file.close()
 
